@@ -1,3 +1,4 @@
+from collections import abc
 import getpass
 from typing import Sequence, Iterable, Optional, Tuple, Any, Union
 
@@ -10,27 +11,54 @@ from . import utils
 
 __all__ = ('get_historian', 'get_meta', 'update_meta', 'set_meta', 'find_meta', 'save_one',
            'save_many', 'get_abspath', 'load', 'to_obj_id', 'get_obj_id', 'init', 'reset',
-           'get_path', 'get_paths', 'rename', 'homedir')
+           'get_path', 'get_paths', 'rename', 'homedir', 'connect')
+
+_HISTORIAN = None  # type: Optional[mincepy.Historian]
+
+
+def connect(uri: str = '') -> mincepy.Historian:
+    mincepy.connect(uri, use_globally=True)
+    return init()
+
+
+def init():
+    # Make sure the indexes are there
+    global _HISTORIAN  # pylint: disable=global-statement
+    historian = mincepy.get_historian()
+    if historian is _HISTORIAN:
+        return historian
+
+    historian.meta.create_index([
+        (config.NAME_KEY, mincepy.ASCENDING),
+        (config.DIR_KEY, mincepy.ASCENDING),
+    ],
+                                unique=True,
+                                where_exist=True)
+
+    # Set the current path
+    path = '/{}/'.format(getpass.getuser())
+    historian.meta.sticky[config.DIR_KEY] = path
+
+    # All done
+    _HISTORIAN = historian
+    return historian
 
 
 def get_historian():
     """Get the active historian in pyos"""
-    return mincepy.get_historian()
-
-
-def init():
-    mincepy.get_historian().meta.create_index([
-        (config.NAME_KEY, mincepy.ASCENDING),
-        (config.DIR_KEY, mincepy.ASCENDING),
-    ],
-                                              unique=True,
-                                              where_exist=True)
-    path = '/{}/'.format(getpass.getuser())
-    get_historian().meta.sticky[config.DIR_KEY] = path
+    global _HISTORIAN  # pylint: disable=global-statement
+    historian = mincepy.get_historian(create=False)
+    if historian is not None and historian is not _HISTORIAN:
+        raise RuntimeError("PyOS has not been initialised with the current historian.  "
+                           "Call pyos.db.init()")
+    return _HISTORIAN
 
 
 def reset():
-    get_historian().meta.sticky.pop(config.DIR_KEY, None)
+    global _HISTORIAN  # pylint: disable=global-statement
+    if _HISTORIAN is not None:
+        _HISTORIAN.meta.sticky.pop(config.DIR_KEY, None)
+        _HISTORIAN = None
 
 
 # region metadata
@@ -140,7 +168,7 @@ def save_one(obj, path: os.PathSpec = None, overwrite=False, historian=None):
     if path is None:
         # Check if it's already saved (in which case we don't need to set a path)
         if hist.get_obj_id(obj) is None:
-            path = './'
+            path = os.getcwd()
 
     meta = None
     if path is not None:
@@ -171,7 +199,7 @@ def save_many(to_save: Iterable[Union[Any, Tuple[Any, os.PathSpec]]],
     obj_ids = []
     for entry in to_save:
         path = None
-        if isinstance(entry, Sequence):
+        if isinstance(entry, abc.Sequence):
             if len(entry) > 2:
                 raise ValueError("Can only pass sequences of at most length 2")
             obj, path = entry[0], entry[1]
