@@ -1,6 +1,6 @@
 """Higher-level classes and functions for browsing the database as a filesystem"""
 
 from .nodes import *
-from . import nodes
+from .utils import *
 
-__all__ = nodes.__all__
+__all__ = nodes.__all__ + utils.__all__
