@@ -1,12 +1,14 @@
 from pyos.db import queries
 from .flags import *
 from .cmds import *
+from .shell import *
 from . import flags
 from . import cmds
 from . import completion
+from . import shell
 
 cwd = completion.PathCompletion('.')  # pylint: disable=invalid-name
 
 _ADDITIONAL = 'queries', 'completion', 'cwd'
 
-__all__ = cmds.__all__ + flags.__all__ + _ADDITIONAL
+__all__ = cmds.__all__ + flags.__all__ + shell.__all__ + _ADDITIONAL
