@@ -1,7 +1,11 @@
-import mincepy
+import argparse
+
+import cmd2
 
 import pyos
+from pyos import db
 from pyos import psh
+from pyos.psh import base
 
 
 @pyos.psh_lib.command()
@@ -13,7 +17,7 @@ def cat(*obj_or_ids, representer=None):
     if not obj_or_ids:
         return None
 
-    hist = mincepy.get_historian()
+    hist = db.get_historian()
     to_cat = []
 
     for entry in obj_or_ids:
@@ -43,3 +47,14 @@ def cat(*obj_or_ids, representer=None):
         return pyos.psh_lib.ResultsString(results[0])
 
     return results
+
+
+class Cat(cmd2.CommandSet):
+    ls_parser = argparse.ArgumentParser()
+    ls_parser.add_argument('path', nargs='*', type=str, completer_method=base.file_completer)
+
+    @cmd2.with_argparser(ls_parser)
+    def do_cat(self, app: cmd2.Cmd, args):  # pylint: disable=no-self-use
+        command = cat
+
+        app.poutput(command(*args.path))
