@@ -1,11 +1,12 @@
 """The history command"""
 
 import pyos
+from pyos import db
 from .cat import cat
 
 
 @pyos.psh_lib.command()
 def history(obj):
-    hist = pyos.db.get_historian()
+    hist = db.get_historian()
     for entry in hist.history(obj):
         cat(entry.obj)
