@@ -1,7 +1,9 @@
 """The locate command"""
-
+import argparse
 from typing import Optional, Union, Sequence
 
+import cmd2
+
 import pyos
 from pyos import psh
 
@@ -17,7 +19,16 @@ def locate(*obj_or_ids) -> Optional[Union[pyos.pathlib.Path, Sequence[pyos.pathl
     paths = [node.abspath for node in to_locate]
     results = pyos.psh_lib.CachingResults(paths.__iter__(), representer=str)
 
-    if len(obj_or_ids) == 1:
+    if len(obj_or_ids) == 1 and len(results) == 1:
         return results[0]
 
     return results
+
+
+class Locate(cmd2.CommandSet):
+    parser = argparse.ArgumentParser()
+    parser.add_argument('obj_ids', nargs='*', type=str)
+
+    @cmd2.with_argparser(parser)
+    def do_locate(self, app: cmd2.Cmd, args):  # pylint: disable=no-self-use
+        app.poutput(locate(*args.obj_ids))
